==> ejc-ztjpoc-impl-3.0.0-20210427.024026-36-sources.jar: com/ejianc/poc/bean/WorkAuthEntity.java <==
package com.ejianc.poc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 工作授权表
 * 
 * @author generator
 * 
 */
@TableName("ejc_ztjpoc_workauth")
public class WorkAuthEntity extends BaseEntity {
	private static final long serialVersionUID = 1L;

	@TableField(value = "target_type")
	private Integer targetType; // 授权对象类型  1 人员 2 岗位
	@TableField(value = "target_id")
	private String targetId; // 授权对象ID 
	@TableField(value = "corp_pk")
	private String corpPk; // 授权对象授权范围组织id
	@TableField(value = "corp_name")
	private String corpName; // 授权对象授权范围组织名称
	@TableField(value = "corp_provider_id")
	private String corpProviderId; // 授权对象授权范围组织所在二级单位id

	@TableField(value = "corp_parent_pk")
	private String corpParentPk; // 授权对象授权范围组织上级id
	@TableField(value = "corp_parent_provider_id")
	private String corpParentProviderId; // 授权对象授权范围组织上级所在二级单位id

	@TableField(value = "provider_id")
	private String providerId; // 授权对象所在二级单位id
	@TableField(value = "org_id")
	private String orgId; // 授权对象 是人员时候是人员主岗位，是岗位时候是岗位上级

	/**
	 * 授权对象类型
	 */
	public Integer getTargetType() {
		return targetType;
	}

	/**
	 * 授权对象类型
	 */
	public void setTargetType(Integer targetType) {
		this.targetType = targetType;
	}

	/**
	 * 授权对象ID
	 */
	public String getTargetId() {
		return targetId;
	}

	/**
	 * 授权对象ID
	 */
	public void setTargetId(String targetId) {
		this.targetId = targetId;
	}

	/**
	 * 公司pk
	 */
	public String getCorpPk() {
		return corpPk;
	}

	/**
	 * 公司pk
	 */
	public void setCorpPk(String corpPk) {
		this.corpPk = corpPk;
	}

	/**
	 * 组织id
	 */
	public String getOrgId() {
		return orgId;
	}

	/**
	 * 组织id
	 */
	public void setOrgId(String orgId) {
		this.orgId = orgId;
	}

	public String getProviderId() {
		return providerId;
	}

	public void setProviderId(String providerId) {
		this.providerId = providerId;
	}

	public String getCorpProviderId() {
		return corpProviderId;
	}

	public void setCorpProviderId(String corpProviderId) {
		this.corpProviderId = corpProviderId;
	}

	public String getCorpName() {
		return corpName;
	}

	public void setCorpName(String corpName) {
		this.corpName = corpName;
	}

	public String getCorpParentPk() {
		return corpParentPk;
	}

	public void setCorpParentPk(String corpParentPk) {
		this.corpParentPk = corpParentPk;
	}

	public String getCorpParentProviderId() {
		return corpParentProviderId;
	}

	public void setCorpParentProviderId(String corpParentProviderId) {
		this.corpParentProviderId = corpParentProviderId;
	}
}

==> ejc-ztjpoc-impl-3.0.0-20210926.083944-73-sources.jar: com/ejianc/poc/bean/WorkAuthEntity.java <==
package com.ejianc.poc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 工作授权表
 * 
 * @author generator
 * 
 */
@TableName("ejc_ztjpoc_workauth")
public class WorkAuthEntity extends BaseEntity {
	private static final long serialVersionUID = 1L;

	@TableField(value = "target_type")
	private Integer targetType; // 授权对象类型  1 人员 2 岗位
	@TableField(value = "target_id")
	private String targetId; // 授权对象ID 
	@TableField(value = "corp_pk")
	private String corpPk; // 授权对象授权范围组织id
	@TableField(value = "corp_code")
	private String corpCode; // 授权对象授权范围组织code
	@TableField(value = "corp_name")
	private String corpName; // 授权对象授权范围组织名称
	@TableField(value = "corp_provider_id")
	private String corpProviderId; // 授权对象授权范围组织所在二级单位id

	@TableField(value = "corp_parent_pk")
	private String corpParentPk; // 授权对象授权范围组织上级id
	@TableField(value = "corp_parent_provider_id")
	private String corpParentProviderId; // 授权对象授权范围组织上级所在二级单位id

	@TableField(value = "provider_id")
	private String providerId; // 授权对象所在二级单位id
	@TableField(value = "org_id")
	private String orgId; // 授权对象 是人员时候是人员主岗位，是岗位时候是岗位上级

	/**
	 * 授权对象类型
	 */
	public Integer getTargetType() {
		return targetType;
	}

	/**
	 * 授权对象类型
	 */
	public void setTargetType(Integer targetType) {
		this.targetType = targetType;
	}

	/**
	 * 授权对象ID
	 */
	public String getTargetId() {
		return targetId;
	}

	/**
	 * 授权对象ID
	 */
	public void setTargetId(String targetId) {
		this.targetId = targetId;
	}

	/**
	 * 公司pk
	 */
	public String getCorpPk() {
		return corpPk;
	}

	/**
	 * 公司pk
	 */
	public void setCorpPk(String corpPk) {
		this.corpPk = corpPk;
	}

	/**
	 * 组织id
	 */
	public String getOrgId() {
		return orgId;
	}

	/**
	 * 组织id
	 */
	public void setOrgId(String orgId) {
		this.orgId = orgId;
	}

	public String getProviderId() {
		return providerId;
	}

	public void setProviderId(String providerId) {
		this.providerId = providerId;
	}

	public String getCorpProviderId() {
		return corpProviderId;
	}

	public void setCorpProviderId(String corpProviderId) {
		this.corpProviderId = corpProviderId;
	}

	public String getCorpCode() {
		return corpCode;
	}

	public void setCorpCode(String corpCode) {
		this.corpCode = corpCode;
	}

	public String getCorpName() {
		return corpName;
	}

	public void setCorpName(String corpName) {
		this.corpName = corpName;
	}

	public String getCorpParentPk() {
		return corpParentPk;
	}

	public void setCorpParentPk(String corpParentPk) {
		this.corpParentPk = corpParentPk;
	}

	public String getCorpParentProviderId() {
		return corpParentProviderId;
	}

	public void setCorpParentProviderId(String corpParentProviderId) {
		this.corpParentProviderId = corpParentProviderId;
	}
}
